==> zio-aws-macie2_2.12-5.17.104.3-sources.jar: zio/aws/macie2/model/ListInvitationsResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListInvitationsResponse(
    invitations: Option[Iterable[zio.aws.macie2.model.Invitation]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListInvitationsResponse = {
    import ListInvitationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
      .builder()
      .optionallyWith(
        invitations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.invitations)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListInvitationsResponse.ReadOnly =
    zio.aws.macie2.model.ListInvitationsResponse.wrap(buildAwsValue())
}
object ListInvitationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListInvitationsResponse =
      zio.aws.macie2.model.ListInvitationsResponse(
        invitations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def invitations: Option[List[zio.aws.macie2.model.Invitation.ReadOnly]]
    def nextToken: Option[__string]
    def getInvitations
        : ZIO[Any, AwsError, List[zio.aws.macie2.model.Invitation.ReadOnly]] =
      AwsError.unwrapOptionField("invitations", invitations)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ) extends zio.aws.macie2.model.ListInvitationsResponse.ReadOnly {
    override val invitations
        : Option[List[zio.aws.macie2.model.Invitation.ReadOnly]] = scala
      .Option(impl.invitations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.Invitation.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ): zio.aws.macie2.model.ListInvitationsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.155.1-sources.jar: zio/aws/macie2/model/ListInvitationsResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListInvitationsResponse(
    invitations: Option[Iterable[zio.aws.macie2.model.Invitation]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListInvitationsResponse = {
    import ListInvitationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
      .builder()
      .optionallyWith(
        invitations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.invitations)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListInvitationsResponse.ReadOnly =
    zio.aws.macie2.model.ListInvitationsResponse.wrap(buildAwsValue())
}
object ListInvitationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListInvitationsResponse =
      zio.aws.macie2.model.ListInvitationsResponse(
        invitations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def invitations: Option[List[zio.aws.macie2.model.Invitation.ReadOnly]]
    def nextToken: Option[__string]
    def getInvitations
        : ZIO[Any, AwsError, List[zio.aws.macie2.model.Invitation.ReadOnly]] =
      AwsError.unwrapOptionField("invitations", invitations)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ) extends zio.aws.macie2.model.ListInvitationsResponse.ReadOnly {
    override val invitations
        : Option[List[zio.aws.macie2.model.Invitation.ReadOnly]] = scala
      .Option(impl.invitations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.Invitation.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListInvitationsResponse
  ): zio.aws.macie2.model.ListInvitationsResponse.ReadOnly = new Wrapper(impl)
}
